@@ -12,7 +12,7 @@ class Literals(ValueDictsBase):
     _info = {
         "cloudfront_invalidation_created": _("Created CloudFront invalidation with id {id}"),
         "s3_downloaded_object_from_s3_bucket":
-            _("Downloaded object with key {name} from bucket {bucket} to {destination}"),
+            _("Downloaded object with key \"{name}\" from bucket {bucket} to {destination}"),
         "s3_downloading_objects_from_s3_bucket":
             _("Downloading {number} objects from bucket {bucket} to {destination}"),
         "s3_got_x_objects_from_s3_bucket": _("Got a list of {number} objects from the {bucket} bucket"),
